From: Drew Wilson <drewmwilson@gmail.com>
To: Heikki Linnakangas <heikki@enterprisedb.com>
Cc: Alvaro Herrera <alvherre@commandprompt.com>
Cc: pgsql-performance@postgresql.org
Subject: Re: Many to many join seems slow?
Date: Tue, 15 May 2007 09:45:07 -0700
Message-ID: <A1B60119-8777-4CAF-AF80-B776751B8670@gmail.com> (raw)
In-Reply-To: <4649C0F3.2070300@enterprisedb.com>
References: <49735678-25F5-48AA-B464-0864BAE56B55@gmail.com>
<20070515140505.GF6298@alvh.no-ip.org>
<2FD25590-AAE3-47AE-9E75-42D1361C38E2@gmail.com>
<4649C0F3.2070300@enterprisedb.com>
You're right. If I redirect output to /dev/null, the query completes
in 1.4s.
# \o /dev/null
# SELECT s.source_id, s.value as sourceValue, t.value as
translationValue...
...
Time: 1409.557 ms
#
That'll do for now.
Thanks,
Drew
On May 15, 2007, at 7:17 AM, Heikki Linnakangas wrote:
> Drew Wilson wrote:
>> Merge Join (cost=524224.49..732216.29 rows=92447 width=97)
>> (actual time=1088.871..1351.840 rows=170759 loops=1)
>> ...
>> Total runtime: 1366.757 ms
>
> It looks like the query actual runs in less than 3 seconds, but it
> takes some time to fetch 170759 rows to the client.
>
> --
> Heikki Linnakangas
> EnterpriseDB http://www.enterprisedb.com
Reply instructions:
You may reply publicly to this message via plain-text email
using any one of the following methods:
* Reply to all the recipients using the --to and --cc options:
reply via email
To: pgsql-performance@postgresql.org
Cc: drewmwilson@gmail.com, heikki@enterprisedb.com, alvherre@commandprompt.com
Subject: Re: Many to many join seems slow?
In-Reply-To: <A1B60119-8777-4CAF-AF80-B776751B8670@gmail.com>
* Save the following mbox file, import it into your mail client,
and reply-to-all from there: mbox
This inbox is served by DDX for PostgreSQL; see mirroring instructions
for how to clone and mirror all data and code used for this inbox